//*****************************************************************************
//
// qtmixer - an X windows soundcard mixer program.
// Copyright (C) 1997 - 2000  Tom Daley
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The license is in the file COPYING.
//
// Tom Daley
// 1309 W. Lorraine Ave.
// Woodland Park, CO  80863-2329
//
// daley@codenet.net (Tom Daley)
// http://users.codenet.net/daley
//
//*****************************************************************************

#include <qpmcache.h> 

#include "channel.h"

//*****************************************************************************

QtedMixerChannel::
QtedMixerChannel(int number, QString label, int left = 0, int right = 0,
                 int record_flag, QWidget *parent = 0, const char *name = 0) : 
   QWidget(parent, name), _number(number), _recordable(record_flag) {

   _label_p = new QLabel(label, this);
   _label_p->setAlignment(AlignHCenter);

   _ss_p = new QtedStereoSlider(left, right, this);
   connect(_ss_p, SIGNAL(valueChanged()), this, SLOT(setValue()));

// make a button even though it won't be displayed
// it will be used in resize calculations

   _record_button_p = new QPushButton("Rec", this);
   if (!_recordable)
       _record_button_p->hide();

   _record_button_p->setToggleButton(1);

// if button gets pressed, emit a signal
   connect(_record_button_p, SIGNAL(clicked()), this, SLOT(recPressed()));

   resizeEvent(NULL);
}

//*****************************************************************************

void QtedMixerChannel::
resizeEvent(QResizeEvent *ev_p) {
   int y = 0;
   int space = 4;
   int button_ht = fontMetrics().lineSpacing() + space;
   int slider_ht = height() - (button_ht * 2) - (space * 2);
   int slider_wd = width() - space * 2;

   _label_p->setGeometry(0, y, width(), button_ht);
   y += button_ht;
   _ss_p->setGeometry(space, y, slider_wd, slider_ht);
   y += slider_ht + space;
   _record_button_p->setGeometry(space, y, slider_wd, button_ht);
}

//*****************************************************************************

void QtedMixerChannel::
setMono(int flag) {
   _ss_p->setMono(flag);
}

//*****************************************************************************

int QtedMixerChannel::
number(void) {
   return (_number);
}

//*****************************************************************************

int QtedMixerChannel::
leftValue(void) {
   return (_ss_p->leftValue());
}

//*****************************************************************************

int QtedMixerChannel::
rightValue(void) {
   return (_ss_p->rightValue());
}

//*****************************************************************************

int QtedMixerChannel::
recordOn(void) {
   return(_record_button_p->isOn());
}

//*****************************************************************************

void QtedMixerChannel::
setRecord(int state) {
   _record_button_p->setOn(state);
}

//*****************************************************************************

void QtedMixerChannel::
recPressed() { 
   emit recordPressed(this); 
}

//*****************************************************************************

void QtedMixerChannel::
setValue() { 
   emit valueChanged(this);
}

//*****************************************************************************
